@@ -1,10 +1,12 @@
-from examples.custom_xml_loader import PyI18nXMLLoader
+# flake8: noqa
+import examples.custom_xml_loader
 
 from tests.helpers import custom_loader_path
 
+
 def test_custom_loader():
-    loader = PyI18nXMLLoader(custom_loader_path)
+    loader = examples.custom_xml_loader.PyI18nXMLLoader(custom_loader_path)
     locales: tuple = ("en", "pl")
     loaded_locales = loader.load(locales)
     assert loaded_locales != {}
-    assert tuple(loaded_locales.keys()) == locales
\ No newline at end of file
+    assert tuple(loaded_locales.keys()) == locales
